(function() {
	/*
	 * CameraOptionsのプロパティの説明：
	 * 		quality          : Number	イメージの画質を指定します。 範囲: 0から100
	 * 		destinationType  : Camera.DestinationType	画像の取得形式です。（Base64 or URI）
	 * 		sourceType       : Camera.PictureSourceType	画像の選択方法です。
	 * 		allowEdit        : boolean	イメージ選択の前に、簡単な編集を許可します。
	 * 		encodingType     : Camera.EncodingType	画像の形式（JPEG,PNG）を選択します。
	 * 		targetWidth      : Number	画像をスケールするための幅をピクセルで指定します。
	 * 		targetHeight     : Number	画像をスケールするための高さをピクセルで指定します。
	 * 		popoverOptions   : CameraPopoverOptions
	 * 		saveToPhotoAlbum : boolean	写真を取得した際、アルバムに保存します。
	 *
	 * CameraOptionsの引数一覧：
	 * 		DestinationType.DATA_URL			画像を Base64 形式で取得
	 * 		DestinationType.FILE_URI			画像をファイル URI として取得
	 * 		PictureSourceType.PHOTOLIBRARY		写真ライブラリから取得
	 * 		PictureSourceType.CAMERA			写真を撮る
	 * 		PictureSourceType.SAVEDPHOTOALBUM	アルバムから取得
	 * 		EncodingType.JPEG					画像を JPEG 形式で取得
	 * 		EncodingType.PNG					画像を PNG 形式で取得
	 * 		MediaType.PICTURE					取得元は静止画像のみとします。
	 * 		MediaType.VIDEO						取得元はビデオのみとします。
	 * 		MediaType.ALLMEDIA					全てのメディアタイプからの取得を許可します。
	 * 		PopoverArrowDirection.ARROW_UP		ポップオーバの矢印（上）
	 * 		PopoverArrowDirection.ARROW_DOWN	ポップオーバの矢印（下）
	 * 		PopoverArrowDirection.ARROW_LEFT	ポップオーバの矢印（左）
	 * 		PopoverArrowDirection.ARROW_RIGHT	ポップオーバの矢印（右）
	 * 		PopoverArrowDirection.ARROW_ANY		ポップオーバの矢印
	 */

	//画像データ
	var imageData = null;

	/*
	 * 撮影してBase64で取得
	 */
	getPictureByBase64 = function() {
		var options = {
			quality         : 90,
			destinationType : applican.camera.DestinationType.DATA_URL,
			sourceType      : applican.camera.PictureSourceType.CAMERA,
			encodingType    : applican.camera.EncodingType.JPEG,
			targetWidth     : 3264,
			targetHeight    : 2448
		};
		applican.camera.getPicture(getPictureByBase64Success, getPictureByBase64Error, options);
	}

	/*
	 * 撮影してBase64で取得成功時のCallback処理
	 * 	res：画像データ
	 */
	function getPictureByBase64Success(res) {
		imageData = res;
		var image = document.getElementById("photoImg");
			image.src = "data:image/jpeg;base64," + res;

		var dump = "画像の撮影に成功しました。\n";
		dump    += "size:" + res.length + "\n";
		alert(dump);
	}

	/*
	 * 撮影してBase64で取得失敗時のCallback処理
	 */
	function getPictureByBase64Error(message) {
		var dump = "画像の撮影に失敗しました。\n";
		dump    += "message:" + message + "\n";
		alert(dump);
	}

	/*
	 * カメラ撮影パスで取得
	 */
	getPictureByPath = function() {
		var options = {
			quality            : 90,
			destinationType    : applican.camera.DestinationType.FILE_URI,
			sourceType         : applican.camera.PictureSourceType.CAMERA,
			encodingType       : applican.camera.EncodingType.JPEG,
			targetWidth        : 3264,
			targetHeight       : 2448,
			saveToPhotoAlbum   : false,
			correctOrientation : true,
			allowEdit          : false
		};
		applican.camera.getPicture(getPictureByPathSuccess, getPictureByPathError, options);
	}

	/*
	 * カメラ撮影パスで取得成功時のCallback処理
	 * 	res：画像のパス
	 */
	function getPictureByPathSuccess(res) {
		imageData = res;
		var image = document.getElementById("photoImg");
		image.src = res;

		var dump = "画像の撮影に成功しました。\n";
		dump    += "path:" + res + "\n";
		alert(dump);
	}

	/*
	 * カメラ撮影パスで取得失敗時のCallback処理
	 */
	function getPictureByPathError(message) {
		var dump = "画像の撮影に失敗しました。\n";
		dump    += "message:" + message + "\n";
		alert(dump);
	}

	/*
	 * ライブラリから画像取得base64で取得
	 */
	getPictureFromLibraryByBase64 = function() {
		var options = {
			quality            : 70,
			destinationType    : applican.camera.DestinationType.DATA_URL,
			sourceType         : applican.camera.PictureSourceType.PHOTOLIBRARY,
			encodingType       : applican.camera.EncodingType.JPEG,
			targetWidth        : 3264,
			targetHeight       : 2448,
			saveToPhotoAlbum   : false,
			correctOrientation : true,
			allowEdit          : true,
			mediaType          : applican.camera.MediaType.PICTURE
		};
		applican.camera.getPicture(getPictureFromLibraryByBase64Success, getPictureFromLibraryByBase64Error, options);
	}

	/*
	 * ライブラリから画像取得base64で取得成功時のCallback処理
	 * 	res：画像データ
	 */
	function getPictureFromLibraryByBase64Success(res) {
		imageData = res;
		var image = document.getElementById("photoImg");
		image.src = "data:image/jpeg;base64," + res;

		var dump = "ライブラリから画像を取得しました。\n";
		dump    += "size:" + res.length + "\n";
		alert(dump);
	}

	/*
	 * ライブラリから画像取得base64で取得失敗時のCallback処理
	 */
	function getPictureFromLibraryByBase64Error(message) {
		var dump = "ライブラリから画像の取得に失敗しました。\n";
		dump    += "message:" + message + "\n";
		alert(dump);
	}

	/*
	 * ライブラリから画像取得ファイルパスを取得
	 */
	getPictureFromLibraryByPath = function() {
		var options = {
			quality            : 70,
			destinationType    : applican.camera.DestinationType.FILE_URI,
			sourceType         : applican.camera.PictureSourceType.PHOTOLIBRARY,
			encodingType       : applican.camera.EncodingType.JPEG,
			targetWidth        : 3264,
			targetHeight       : 2448,
			saveToPhotoAlbum   : false,
			correctOrientation : true,
			allowEdit          : false,
			mediaType          : applican.camera.MediaType.PICTURE
		};
		applican.camera.getPicture(getPictureFromLibraryByPathSuccess, getPictureFromLibraryByPathError, options);
	}

	/*
	 * ライブラリから画像取得ファイルパスを取得成功時のCallback処理
	 * 	res：画像のパス
	 */
	function getPictureFromLibraryByPathSuccess(res) {
		imageData = res;
		var image = document.getElementById("photoImg");
		image.src = res;

		var dump = "ライブラリから画像を取得しました。\n";
		dump    += "path:" + res + "\n";
		alert(dump);
	}

	/*
	 * ライブラリから画像取得ファイルパスを取得失敗時のCallback処理
	 */
	function getPictureFromLibraryByPathError(message) {
		var dump = "ライブラリから画像の取得に失敗しました。\n";
		dump    += "message:" + message + "\n";
		alert(dump);
	}

	/*
	 * 取得した画像を→ライブラリへ保存
	 */
	saveToPhotoAlbum = function() {
		if(imageData === null) {
			alert("先に画像を取得してください");
			return;
		}
		// imageData：Base64形式の文字列、又はファイルのパス
		applican.camera.saveToPhotoAlbum(imageData, saveToPhotoAlbumSuccess, saveToPhotoAlbumError);
	}

	/*
	 * 取得した画像を→ライブラリへ保存成功時のCallback処理
	 */
	function saveToPhotoAlbumSuccess() {
		var dump = "取得した画像をライブラリへ保存しました。\n";
		alert(dump);
	}

	/*
	 * 取得した画像を→ライブラリへ保存失敗時のCallback処理
	 */
	function saveToPhotoAlbumError(message) {
		var dump = "取得した画像をライブラリへ保存に失敗しました。\n";
		dump    += "message:" + message;
		alert(dump);
	}

	/*
	 * カメラ画像クリーンアップ
	 * 一時ディレクトリに保存された画像ファイルを削除する
	 */
	cleanupPicture = function() {
		applican.camera.cleanup(cleanupPictureSuccess, cleanupPictureError);
	}

	/*
	 * カメラ画像クリーンアップ成功時のCallback処理
	 */
	function cleanupPictureSuccess() {
		alert("一時ディレクトリに保存された画像ファイルを削除しました。");
	}

	/*
	 * カメラ画像クリーンアップ失敗時のCallback処理
	 */
	function cleanupPictureError(message) {
		var dump = "一時ディレクトリに保存された画像ファイルの削除に失敗しました。\n";
		dump    += "message:" + message;
		alert(dump);
	}

	/********************* イベント登録 *********************/
	document.addEventListener("deviceready", function() {
		// 「撮影してBase64で取得」ボタン押下処理
		document.getElementById("takePhotoByBase64Btn").addEventListener("touchend", getPictureByBase64, false);
		// 「撮影してファイルパスを取得」ボタン押下処理
		document.getElementById("takePhotoByPathBtn").addEventListener("touchend", getPictureByPath, false);
		// 「ライブラリから選択してbase64で取得」ボタン押下処理
		document.getElementById("getFromPhotoLibByBase64Btn").addEventListener("touchend", getPictureFromLibraryByBase64, false);
		// 「ライブラリから選択してファイルパスを取得」ボタン押下処理
		document.getElementById("getFromPhotoLibByPathBtn").addEventListener("touchend", getPictureFromLibraryByPath, false);
		// 「取得した画像をライブラリへ保存」ボタン押下処理
		document.getElementById("saveToPhotoLibBtn").addEventListener("touchend", saveToPhotoAlbum, false);
		// 「カメラ画像クリーンアップ」ボタン押下処理
		document.getElementById("clearupPhotoBtn").addEventListener("touchend", cleanupPicture, false);
	}, false);
})();
